# ora_get

Download an ORA (Oxford Research Archive) collection.

```
ora_get 8d95c423-816c-4a4f-88b6-eb7a040cb40e  # by UUID
```

## License

This codebase is made available under the MIT License, copyright (c) 2023 Tom Russell and contributors. See [./LICENSE](./LICENSE) for details
